Main author:

Adrian Price-Whelan (`@adrn <https://github.com/adrn>`_)

All contributors (alphabetical last name):

- Johnny Greco
- Sergey Koposov
- Daniel Lenz
- Pey Lian Lim
- Syrtis Major
- Semyeong Oh
- Adrian Price-Whelan
- Brigitta Sipocz
- Nathaniel Starkman
